@@ -4,9 +4,11 @@ See https://crppwww.epfl.ch/~sauter/cocos/Sauter_COCOS_Tokamak_Coordinate_Conven
 Especially Table I page 8
 """
 
-
+import logging
 import numpy as np
 
+log = logging.getLogger()
+
 # Table I page 8
 
 sigma = { \
@@ -51,7 +53,7 @@ def check_coco(equ_in, ip_shot='ccw', bt_shot='cw'):
     sigma_bp    = dpsi_sign*sign_ip
 # Eq 45
     sigma_rhothephi = sign_q*sign_ip*sign_bt
-    print(sigma_bp, sigma_rphiz, sigma_rhothephi)
+    log.debug(sigma_bp, sigma_rphiz, sigma_rhothephi)
     for jc, rhothephi in enumerate(sigma['rhothephi']):
         if(sigma['bp'   ][jc] == sigma_bp    and \
            sigma['rphiz'][jc] == sigma_rphiz and \
@@ -67,7 +69,7 @@ def check_coco(equ_in, ip_shot='ccw', bt_shot='cw'):
 # Radial+time average
 # It is either q_ratio ~ 1 (COCO > 10) or ~ 2*pi (COCO < 10)
     q_ratio = np.abs(np.nanmean(dphi/(equ_in.q*dpsi)))
-    print('Ratio %8.4f' %q_ratio)
+    log.debug('Ratio %8.4f' %q_ratio)
     if q_ratio < 4:
         ncoco += 10
 
@@ -97,7 +99,7 @@ def coco2coco(equ_in, cocos_out=11):
 # Assuming SI for both equ_in and equ_out
 
     cocos_in = equ_in.cocos
-    print('COCOS conversion from %d to %d' %(cocos_in, cocos_out))
+    log.info('COCOS conversion from %d to %d' %(cocos_in, cocos_out))
     jc_in   = cocos_in %10 - 1
     jc_out  = cocos_out%10 - 1
     ebp_in  = cocos_in//10
@@ -110,7 +112,7 @@ def coco2coco(equ_in, cocos_out=11):
     psi_2pi  = (2.*np.pi)**(ebp_out - ebp_in)
     psi_fac = psi_sign*psi_2pi
     try:
-        print(np.mean(equ_in.jav), phi_sign)
+        log.debug(np.mean(equ_in.jav), phi_sign)
     except:
         pass
     equ_out = EQUIL()
@@ -147,29 +149,26 @@ if __name__ == '__main__':
     t2 = time.time()
     eq_out = coco2coco(eq_in, cocos_out=12)
     t3 = time.time()
-    print('Time for reading EQU', t2 - t1)
-    print('Time for COCOs conversion', t3 - t2)
+    log.info('Time for reading EQU', t2 - t1)
+    log.info('Time for COCOs conversion', t3 - t2)
     ncoco_in  = check_coco(eq_in )
     ncoco_out = check_coco(eq_out)
-    print('AUG equ_in  has COCO %d' %ncoco_in )
-    print('AUG equ_out has COCO %d' %ncoco_out)
+    log.info('AUG equ_in  has COCO %d' %ncoco_in )
+    log.info('AUG equ_out has COCO %d' %ncoco_out)
 
     br_in , bz_in , bt_in  = meq.Bmesh(eq_in)
     br_out, bz_out, bt_out = meq.Bmesh(eq_out)
     nt, nR, nZ = br_in.shape
-    print(nt, nR, nZ)
+    log.info(nt, nR, nZ)
     jt = nt//2
     jR = nR//2
     jZ = nZ//2
-    print(eq_in.cocos)
-    print(eq_in.pfl[jt])
-    print(eq_in.q[jt])
-    print(eq_out.cocos)
-    print(eq_out.pfl[jt])
-    print(eq_out.q[jt])
-
-#    for key, val in eq_in.__dict__.items():
-#        print(key)
+    log.info(eq_in.cocos)
+    log.info(eq_in.pfl[jt])
+    log.info(eq_in.q[jt])
+    log.info(eq_out.cocos)
+    log.info(eq_out.pfl[jt])
+    log.info(eq_out.q[jt])
 
 # Plot B components
 
