@@ -1,17 +1,15 @@
-import os, struct
-
-verbose = True
-verbose = False
+import os, struct, logging
 
 if os.name == 'nt':
     afs_home = '\/afs/ipp-garching.mpg.de/home'
 else:
     afs_home = '/afs/ipp-garching.mpg.de/home'
 
+log = logging.getLogger()
+
 
 def sf_path(nshot, diag, exp='AUGD', ed=0):
 
-
     sshot = str(nshot).zfill(5)
     exp = exp.lower()
     diag = diag.upper()
@@ -74,8 +72,7 @@ def ed_zero(diag, nshot, exp='augd'):
     ed_d = read_ed_cntl(fed_dir, exp=exp)
     if ed_d is None:
         return None
-    if verbose:
-        print(nshot, ed_d)
+    log.debug(nshot, ed_d)
     if nshot in ed_d.keys():
         return ed_d[nshot]
     else:
@@ -120,10 +117,8 @@ if __name__ == '__main__':
 
     fed_in = '%s/g/git/shotfiles/TRA/35' %afs_home
     ed = read_ed_cntl(fed_in, exp='git')
-    print(fed_in)
-    print(ed)
+    log.info(fed_in, ed) 
     fed_in = '%s/a/augd/shots/3956/L1/NSP' %afs_home
     fed_in = '%s/a/augd/shots/3956/L1/TOT' %afs_home
     ed = read_ed_cntl(fed_in)
-    print(fed_in)
-    print(ed)
+    log.info(fed_in, ed)
