@@ -2,12 +2,13 @@
 Equilibrium utilities library
 """
 
-import sys, time
+import sys, time, logging
 import numpy as np
 from scipy.ndimage.interpolation import map_coordinates
 from scipy.interpolate import UnivariateSpline, interp1d, InterpolatedUnivariateSpline, RectBivariateSpline
 from . import cocos
 
+log = logging.getLogger()
 
 def get_nearest_index(tim_eq, tarr):
     """Find nearest time index for a given time"""
@@ -205,11 +206,11 @@ def rz2brzt(eqm, r_in, z_in, t_in=None):
     nrz_in = r_in.shape[-1]
 
     if r_in.shape != z_in.shape:
-        print('r_in and z_in must have the same shape')
+        log.error('r_in and z_in must have the same shape')
         return
 
     if r_in.ndim == 2 and r_in.shape[0] != nt:
-        print('Time array missmatching first dim of r_in')
+        log.error('Time array missmatching first dim of r_in')
         return
 
     if np.size(r_in, 0)!= nt:
@@ -237,7 +238,7 @@ def rz2brzt(eqm, r_in, z_in, t_in=None):
     psi_sign = sigma_ip*cocos.sigma['bp'][jc_in]
     psi_2pi  = (2.*np.pi)**ebp_in
     psi_fac = psi_sign*psi_2pi
-    print('COCOS %d, Sign Bt %d, Sign Ip %d' %(cocos_in, sign_b0, sign_ip))
+    log.debug('COCOS %d, Sign Bt %d, Sign Ip %d' %(cocos_in, sign_b0, sign_ip))
 
     unique_idx, index_idx =  get_nearest_index(eqm.time, tarr)
 
@@ -309,7 +310,7 @@ def Bmesh(eqm, t_in=None):
     psi_sign = cocos.sigma['bp'][jc_in]
     psi_2pi  = (2.*np.pi)**ebp_in
     psi_fac = psi_sign*psi_2pi
-    print('COCOS %d' %cocos_in)
+    log.info('COCOS %d' %cocos_in)
 
     unique_idx, index_idx =  get_nearest_index(eqm.time, tarr)
 
@@ -461,7 +462,7 @@ def rho2rz(eqm, rho_in, t_in=None, coord_in='rho_pol', all_lines=False):
         try:
             cgen = _contour.QuadContourGenerator(R, Z, eqm.pfm[:nr, :nz, i].T, None, True, 0)
         except Exception as e:
-            print(R.shape, Z.shape, eqm.pfm[:nr, :nz, i].T.shape)
+            log.exception(R.shape, Z.shape, eqm.pfm[:nr, :nz, i].T.shape)
             raise e 
 
         Rs_t = []
@@ -565,7 +566,7 @@ def cross_surf(eqm, rho=1., r_in=1.65, z_in=0, theta_in=0, t_in=None, coord_in='
         ind_gt = (rho_line[i] > rho)
         ind_cross = [j for j, x in enumerate(np.diff(ind_gt)) if x]
         if len(ind_cross) > 2:
-            print('More than 2 intersections, problems')
+            log.warning('More than 2 intersections, problems')
             zout[jt, :] = 0
             Rout[jt, :] = 0
             continue
@@ -641,7 +642,7 @@ def cross_sep(eqm, r_in=1.65, z_in=0, theta_in=0, t_in=None):
         ind_gt = (psi_line[i] > psi_sep[ii])
         ind_cross = [j for j, x in enumerate(np.diff(ind_gt)) if x]
         if len(ind_cross) > 2:
-            print('More than 2 intersections, problems')
+            log.warning('More than 2 intersections, problems')
             zout[jt, :] = 0
             Rout[jt, :] = 0
             continue
