@@ -1,10 +1,12 @@
 PROJECT_NAME="Equilibrium object from shotfile"
 
-import sys
+import sys, logging
 import numpy as np
 
 from . import sfobj, SFREAD, parse_kwargs
 
+log = logging.getLogger()
+
 
 class EMPTY:
 
@@ -84,15 +86,17 @@ class EQU:
                 ind_sol  = np.arange(self.lpfp[jt] + 3, self.lpfp[jt] + 3 + self.lpfe[jt])
                 self.ind_sort.append(np.append(ind_core, ind_sol))
         else:
-            print('Problems opening %s:%s:%d for shot %d' %(exp, diag, ed, nshot))
-        print('Reading equ scalars')
+            log.error('Problems opening %s:%s:%d for shot %d' %(exp, diag, ed, nshot))
+            return
+
+        log.info('Reading equ scalars')
         self.read_scalars()
-        print('Reading equ 1d profiles')
+        log.info('Reading equ 1d profiles')
         self.read_profiles()
-        print('Reading equ PFM')
+        log.info('Reading equ PFM')
         self.read_pfm()
 
-        print('COCOS %d' %self.cocos)
+        log.info('Detected COCO %d' %self.cocos)
 
         if 'tbeg' in kwargs.keys():
             tbeg = kwargs['tbeg']
@@ -219,7 +223,7 @@ class EQU:
             ## Plasma current[A]
             self.ipipsi = self.sf.getobject('IpiPSI')[:nt]
         except:
-            print('Signal IpiPSI not found')
+            log.exception('Signal IpiPSI not found')
 
 
     def read_profiles(self):
@@ -268,7 +272,7 @@ class EQU:
         profs = ('TFLx', 'PFL', 'FFP', 'Qpsi', 'Rinv', 'R2inv', 'Bave', 'B2ave')
 
         if var_name not in profs:
-            print('SignalGroup %s unknown' %var_name)
+            log.error('SignalGroup %s unknown' %var_name)
             return None
 
         tmp = self.sf.getobject(var_name)
@@ -308,7 +312,7 @@ class EQU:
 # Pairs prof, d(prof)/d(psi)
 
         if var_name not in mixed:
-            print('%s not one of the mixed quanties Vol, Area, Pres, Jpol' %var_name)
+            log.error('%s not one of the mixed quanties Vol, Area, Pres, Jpol' %var_name)
             return None, None
 
         tmp = self.sf.getobject(var_name)
@@ -343,4 +347,4 @@ if __name__ == '__main__':
 
     nshot = 28053
     eqm = EQU(nshot)
-    print(eqm.ssqnames)
+    log.info(eqm.ssqnames)
