@@ -1,4 +1,4 @@
-import shutil, os
+import shutil, os, logging
 import ctypes as ct
 import numpy as np
 from . import sfdics, str_byt
@@ -6,6 +6,8 @@ from . import sfdics, str_byt
 sfhlib = '/afs/ipp/aug/ads/lib64/amd64_sles11/libsfh8.so.20201118'
 libsfh = ct.cdll.LoadLibrary(sfhlib)
 
+log = logging.getLogger()
+
 
 class SFH:
 
@@ -107,7 +109,7 @@ class SFH:
         _len  = ct.byref(c_len)
 # Output
 
-        print('Modpar test:', pn, typ, pnlen, len(dat))
+        log.debug('Modpar test:', pn, typ, pnlen, len(dat))
         if fmt in sfdics.fmt2len.keys():
             name_len = sfdics.fmt2len[fmt]
             c_len  = ct.c_uint32(pnlen)
