@@ -1,11 +1,11 @@
-import os, time
+import os, time, logging
 from struct import unpack
 import numpy as np
 from . import sfdics, str_byt
 
 n_rel = 8
-verbose = False
-#verbose = True
+
+log = logging.getLogger()
 
 def read_sfh(byt_str):
     """
@@ -58,8 +58,7 @@ def read_sfh(byt_str):
             break
 
     tend = time.time()
-    if verbose:
-        print('Time SFHread: %8.4f' %(tend - tbeg))
+    log.debug('Time SFHread: %8.4f' %(tend - tbeg))
 
     return sfhead
 
