@@ -1,13 +1,13 @@
-import os, datetime
+import os, datetime, logging
 from struct import unpack
 import numpy as np
 
 from . import sfdics, sfhread, sfobj, manage_ed, parse_kwargs, str_byt
 
-verbose = True
-verbose = False
 PPGCLOCK = [1e-6, 1e-5, 1e-4, 1e-3]
 
+log = logging.getLogger()
+
 
 def parse_url(url, blen=100):
     """
@@ -26,29 +26,29 @@ def parse_url(url, blen=100):
                 import urllib
                 url_lib = 'urllib'
             except:
-                print('No URL lib found, exiting')
+                log.error('No URL lib found, exiting')
                 return None
-    print('URL reading with %s' %url_lib)
+    log.info('URL reading with %s' %url_lib)
     url_not_found = 'URLs %s not found, exiting' %url
     if url_lib == 'urllib3':
         http = urllib3.PoolManager()
         try:
             tmp = http.request('GET', url)
         except:
-            print(url_not_found)
+            log.error(url_not_found)
             return None
         bshot = tmp.data
     elif url_lib == 'urllib2':
         try:
             bshot = urllib2.urlopen(url).read(blen)
         except:
-            print(url_not_found)
+            log.exception(url_not_found)
             return None
     elif url_lib == 'urllib':
         try:
             bshot = request.urlopen(url).read()
         except:
-            print(url_not_found)
+            log.exception(url_not_found)
             return None
 
     return bshot
@@ -69,7 +69,7 @@ def getlastshot():
             page = str_byt.to_str(page)
             idx = page.find("Current shot:")
             if idx < 0:
-                print('Missing substring "Current shot:" in %s, exiting' %url2)
+                log.warning('Missing substring "Current shot:" in %s, exiting' %url2)
                 return None
             substr = page[idx:idx+30]
             a = substr.find('>')+1
@@ -80,7 +80,7 @@ def getlastshot():
         try:
             nshot = int(sshot)
         except:
-            print('ERROR sfread.getlastshot: cannot convert string %s to integer' %sshot)
+            log.exception('ERROR sfread.getlastshot: cannot convert string %s to integer' %sshot)
             nshot = None
 
     return nshot
@@ -173,7 +173,7 @@ class SFREAD:
 
             n_args = len(args) 
             if n_args == 0:
-                print('No argument given, need at least diag_name')
+                log.warning('No argument given, need at least diag_name')
                 return
             if isinstance(args[0], str) and len(args[0].strip()) == 3:
                 diag = args[0].strip()
@@ -186,7 +186,7 @@ class SFREAD:
                     if isinstance(args[1], str) and len(args[1].strip()) == 3:
                         diag = args[1].strip()
             if 'nshot' not in locals(): 
-                print('No argument is a shot number (int), taking last AUG shot')
+                log.warning('No argument is a shot number (int), taking last AUG shot')
                 nshot = getlastshot()
             if 'diag' not in locals():
                 diag = input('Please enter a diag_name (str(3), no delimiter):\n')
@@ -196,6 +196,7 @@ class SFREAD:
 
             self.sfile, self.ed = manage_ed.sf_path(nshot, diag, exp=exp, ed=ed)
             if self.sfile is None:
+                log.error('Shotfile not found')
                 return
             else:
                 self.shot = nshot
@@ -207,12 +208,13 @@ class SFREAD:
             with open(self.sfile, 'rb') as f:
                 byt_str = f.read(128000)
                 if len(byt_str) < 128:
-                    print('Error: shotfile %s has < 128 bytes, ignored' %(self.sfile))
+                    log.error('Error: shotfile %s has < 128 bytes, ignored' %(self.sfile))
                     return
                 self.sfh = sfhread.read_sfh(byt_str)
                 self.status = True
         else:
-            print('Shotfile %s not found' %self.sfile)
+            log.error('Shotfile %s not found' %self.sfile)
+            return
 
         if self.status:
             self.objects = [ lbl for lbl in self.sfh['obj_nam'] if self.sfh[lbl].obj_type in [6, 7, 8, 13] ]
@@ -297,7 +299,7 @@ class SFREAD:
 
         sfo = self.sfh[obj]
         if sfo.status != 0:
-            print('Status of SF object %s is %d' %(obj, sfo.status))
+            log.error('Status of SF object %s is %d' %(obj, sfo.status))
             return None
         otyp = sfo.obj_type
         if otyp in (6, 7):
@@ -413,7 +415,7 @@ class SFREAD:
             if self.sfh[rel].obj_type == 4:
                 caltyp = str_byt.to_str(sfdics.cal_type[self.sfh[rel].cal_type])
                 if caltyp == 'LinCalib':
-                    print('PSet for calib: %s' %rel)
+                    log.info('PSet for calib: %s' %rel)
                     return self.getparset(rel)
         return None
 
@@ -440,8 +442,7 @@ class SFREAD:
             meta = type('', (), {})()
 #            meta.phys_unit = sfdics.unit_d[unit]
             meta.data_format = dfmt
-            if verbose:
-                print(pname, unit, dfmt, n_items)
+            log.debug(pname, unit, dfmt, n_items)
             status = unpack('>h', buf[j0+14:  j0+16])[0]
             j0 += 16
             if dfmt in sfdics.fmt2len.keys(): # char variable
@@ -463,8 +464,7 @@ class SFREAD:
                 dj0 = 8 * ( (bytlen + 7)//8 )
                 j0 += dj0
 
-            if verbose:
-                print(pname, data)
+            log.debug(pname, data)
             par_d[pname] = sfobj.SFOBJ(data, sfho=meta)
 
         return par_d
